@@ -1,8 +1,10 @@
 from fractions import Fraction
 from itertools import chain
-from typing import (Iterator,
+from typing import (Iterable,
+                    Iterator,
                     List,
-                    Sequence)
+                    Sequence,
+                    Tuple)
 
 from robust.angular import (Orientation,
                             orientation)
@@ -20,13 +22,12 @@ from hypothesis_geometry.hints import (Contour,
 flatten = chain.from_iterable
 
 
-def split(sequence: Sequence[Domain],
-          *,
-          size: int = 2) -> List[Sequence[Domain]]:
-    step, offset = divmod(len(sequence), size)
-    return [sequence[number * step + min(number, offset):
-                     (number + 1) * step + min(number + 1, offset)]
-            for number in range(size)]
+def pairwise(iterable: Iterable[Domain]) -> Iterable[Tuple[Domain, Domain]]:
+    iterator = iter(iterable)
+    element = next(iterator)
+    for next_element in iterator:
+        yield element, next_element
+        element = next_element
 
 
 Orientation = Orientation
@@ -61,7 +62,6 @@ def contour_to_centroid(contour: Contour) -> Point:
         prev_x, prev_y = x, y
         prev_vertex = vertex
     denominator = 3 * double_area[-1]
-    assert denominator != 0
     return (_divide_by_int(x_numerator[-1], denominator),
             _divide_by_int(y_numerator[-1], denominator))
 
